Struct chirpstack_api::api::DeviceProfileTemplateListItem
source · pub struct DeviceProfileTemplateListItem {
pub id: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub name: String,
pub vendor: String,
pub firmware: String,
pub region: i32,
pub mac_version: i32,
pub reg_params_revision: i32,
pub supports_otaa: bool,
pub supports_class_b: bool,
pub supports_class_c: bool,
}Fields
id: StringDevice-profile template ID.
created_at: Option<Timestamp>Created at timestamp.
updated_at: Option<Timestamp>Last update timestamp.
name: StringName.
vendor: StringVendor.
firmware: StringFirmware.
region: i32Region.
mac_version: i32LoRaWAN mac-version.
reg_params_revision: i32Regional parameters revision.
supports_otaa: boolSupports OTAA.
supports_class_b: boolSupports Class-B.
supports_class_c: boolSupports Class-C.
Implementations
sourceimpl DeviceProfileTemplateListItem
impl DeviceProfileTemplateListItem
sourcepub fn region(&self) -> Region
pub fn region(&self) -> Region
Returns the enum value of region, or the default if the field is set to an invalid enum value.
sourcepub fn set_region(&mut self, value: Region)
pub fn set_region(&mut self, value: Region)
Sets region to the provided enum value.
sourcepub fn mac_version(&self) -> MacVersion
pub fn mac_version(&self) -> MacVersion
Returns the enum value of mac_version, or the default if the field is set to an invalid enum value.
sourcepub fn set_mac_version(&mut self, value: MacVersion)
pub fn set_mac_version(&mut self, value: MacVersion)
Sets mac_version to the provided enum value.
sourcepub fn reg_params_revision(&self) -> RegParamsRevision
pub fn reg_params_revision(&self) -> RegParamsRevision
Returns the enum value of reg_params_revision, or the default if the field is set to an invalid enum value.
sourcepub fn set_reg_params_revision(&mut self, value: RegParamsRevision)
pub fn set_reg_params_revision(&mut self, value: RegParamsRevision)
Sets reg_params_revision to the provided enum value.