Struct chirpstack_api::api::DeviceQueueItem
source · pub struct DeviceQueueItem {
pub id: String,
pub dev_eui: String,
pub confirmed: bool,
pub f_port: u32,
pub data: Vec<u8>,
pub object: Option<Struct>,
pub is_pending: bool,
pub f_cnt_down: u32,
}Fields
id: StringID (UUID). This is automatically generated on enqueue.
dev_eui: StringDevice EUI (EUI64).
confirmed: boolConfirmed.
f_port: u32FPort (must be > 0).
data: Vec<u8>Data. Or use the json_object field when a codec has been configured.
object: Option<Struct>Only use this when a codec has been configured that can encode this object to bytes.
is_pending: boolIs pending. This is set to true when the downlink is pending.
f_cnt_down: u32Downlink frame-counter. This is set when the payload has been sent as downlink.