FuotaDeployment

Struct FuotaDeployment 

pub struct FuotaDeployment {
Show 22 fields pub id: String, pub application_id: String, pub device_profile_id: String, pub name: String, pub multicast_group_type: i32, pub multicast_class_c_scheduling_type: i32, pub multicast_dr: u32, pub multicast_class_b_ping_slot_periodicity: u32, pub multicast_frequency: u32, pub multicast_timeout: u32, pub calculate_multicast_timeout: bool, pub unicast_max_retry_count: u32, pub fragmentation_fragment_size: u32, pub calculate_fragmentation_fragment_size: bool, pub fragmentation_redundancy_percentage: u32, pub fragmentation_session_index: u32, pub fragmentation_matrix: u32, pub fragmentation_block_ack_delay: u32, pub fragmentation_descriptor: Vec<u8>, pub request_fragmentation_session_status: i32, pub payload: Vec<u8>, pub on_complete_set_device_tags: HashMap<String, String>,
}

Fields

id: String

Deployment ID. This value is automatically set on create.

application_id: String

Application ID.

device_profile_id: String

Device-profile ID.

name: String

Deployment name.

multicast_group_type: i32

Multicast-group type.

multicast_class_c_scheduling_type: i32

Multicast-group scheduling type (Class-C only).

multicast_dr: u32

Multicast data-rate.

multicast_class_b_ping_slot_periodicity: u32

Multicast ping-slot period (Class-B only). Valid options are: 0 - 7.

Number of ping-slots per beacon-period: pingNb = 2^(7-periodicity)

Periodicity: 0 = 128 ping-slots per beacon period = ~ every 1 sec Periodicity: 7 = 1 ping-slot per beacon period = ~ every 128 sec

multicast_frequency: u32

Multicast frequency (Hz).

multicast_timeout: u32

Multicast timeout. This defines the timeout of the multicast-session. Please refer to the Remote Multicast Setup specification as this field has a different meaning for Class-B and Class-C groups.

calculate_multicast_timeout: bool

Calculate multicast timeout. If set to true, ChirpStack will calculate the multicast-timeout.

unicast_max_retry_count: u32

The number of times ChirpStack will retry an unicast command before it considers it to be failed.

fragmentation_fragment_size: u32

Fragmentation size. This defines the size of each payload fragment. Please refer to the Regional Parameters specification for the maximum payload sizes per data-rate and region.

calculate_fragmentation_fragment_size: bool

Calculate fragmentation size. If set to true, ChirpStack will calculate the fragmentation size.

fragmentation_redundancy_percentage: u32

Fragmentation redundancy percentage. The number represents the percentage (0 - 100) of redundant messages to send.

fragmentation_session_index: u32

Fragmentation session index.

fragmentation_matrix: u32

Fragmentation matrix.

fragmentation_block_ack_delay: u32

Block ack delay.

fragmentation_descriptor: Vec<u8>

Descriptor (4 bytes).

request_fragmentation_session_status: i32

Request fragmentation session status.

payload: Vec<u8>

Payload. The FUOTA payload to send.

on_complete_set_device_tags: HashMap<String, String>

Set device tags on complete.

Implementations

Source

impl FuotaDeployment

pub fn multicast_group_type(&self) -> MulticastGroupType

Returns the enum value of multicast_group_type, or the default if the field is set to an invalid enum value.

pub fn set_multicast_group_type(&mut self, value: MulticastGroupType)

Sets multicast_group_type to the provided enum value.

pub fn multicast_class_c_scheduling_type(&self) -> MulticastGroupSchedulingType

Returns the enum value of multicast_class_c_scheduling_type, or the default if the field is set to an invalid enum value.

pub fn set_multicast_class_c_scheduling_type( &mut self, value: MulticastGroupSchedulingType, )

Sets multicast_class_c_scheduling_type to the provided enum value.

pub fn request_fragmentation_session_status( &self, ) -> RequestFragmentationSessionStatus

Returns the enum value of request_fragmentation_session_status, or the default if the field is set to an invalid enum value.

pub fn set_request_fragmentation_session_status( &mut self, value: RequestFragmentationSessionStatus, )

Sets request_fragmentation_session_status to the provided enum value.