GcpPubSubIntegration

Struct GcpPubSubIntegration 

pub struct GcpPubSubIntegration {
    pub application_id: String,
    pub encoding: i32,
    pub credentials_file: String,
    pub project_id: String,
    pub topic_name: String,
}

Fields

application_id: String

Application ID (UUID).

encoding: i32

Encoding.

credentials_file: String

Credentials file. This IAM service-account credentials file (JSON) must have the following Pub/Sub roles:

  • Pub/Sub Publisher
project_id: String

Project ID.

topic_name: String

Topic name. This is the name of the Pub/Sub topic.

Implementations

Source

impl GcpPubSubIntegration

pub fn encoding(&self) -> Encoding

Returns the enum value of encoding, or the default if the field is set to an invalid enum value.

pub fn set_encoding(&mut self, value: Encoding)

Sets encoding to the provided enum value.