Struct chirpstack_api::api::GetDeviceMetricsRequest
source · pub struct GetDeviceMetricsRequest {
pub dev_eui: String,
pub start: Option<Timestamp>,
pub end: Option<Timestamp>,
pub aggregation: i32,
}Fields
dev_eui: StringDevEUI (EUI64).
start: Option<Timestamp>Interval start timestamp.
end: Option<Timestamp>Interval end timestamp.
aggregation: i32Aggregation.
Implementations
sourceimpl GetDeviceMetricsRequest
impl GetDeviceMetricsRequest
sourcepub fn aggregation(&self) -> Aggregation
pub fn aggregation(&self) -> Aggregation
Returns the enum value of aggregation, or the default if the field is set to an invalid enum value.
sourcepub fn set_aggregation(&mut self, value: Aggregation)
pub fn set_aggregation(&mut self, value: Aggregation)
Sets aggregation to the provided enum value.