pub struct ListTenantUsersRequest {
pub tenant_id: String,
pub limit: u32,
pub offset: u32,
}Fields
tenant_id: StringTenant ID (UUID).
limit: u32Max number of tenants to return in the result-set. If not set, it will be treated as 0, and the response will only return the total_count.
offset: u32Offset in the result-set (for pagination).