pub struct RelayGatewayListItem {
pub tenant_id: String,
pub relay_id: String,
pub name: String,
pub description: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub last_seen_at: Option<Timestamp>,
pub state: i32,
pub region_config_id: String,
}Fields
tenant_id: StringTenant ID.
relay_id: StringRelay ID (4 byte HEX).
name: StringName.
description: StringDescription.
created_at: Option<Timestamp>Created at timestamp.
updated_at: Option<Timestamp>Last update timestamp.
last_seen_at: Option<Timestamp>Last seen at timestamp.
state: i32Gateway state. Please note that the state of the relay is driven by the last received stats packet sent by the relay-gateway.
region_config_id: StringRegion configuration ID.
Implementations
Sourceimpl RelayGatewayListItem
impl RelayGatewayListItem
Sourcepub fn state(&self) -> GatewayState
pub fn state(&self) -> GatewayState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: GatewayState)
pub fn set_state(&mut self, value: GatewayState)
Sets state to the provided enum value.