Struct chirpstack_api::as_pb::external::api::DeviceListItem [−][src]
pub struct DeviceListItem {
pub dev_eui: String,
pub name: String,
pub application_id: i64,
pub description: String,
pub device_profile_id: String,
pub device_profile_name: String,
pub device_status_battery: u32,
pub device_status_margin: i32,
pub device_status_external_power_source: bool,
pub device_status_battery_level_unavailable: bool,
pub device_status_battery_level: f32,
pub last_seen_at: Option<Timestamp>,
}Fields
dev_eui: StringDevice EUI (HEX encoded).
name: StringName of the device.
application_id: i64Application ID.
description: StringDescription of the device.
device_profile_id: StringDevice-profile ID attached to the device.
device_profile_name: StringDevice-profile name.
device_status_battery: u32The device battery status (deprecated, use device_status_battery_level). 0: The end-device is connected to an external power source 1..254: The battery level, 1 being at minimum and 254 being at maximum 255: The end-device was not able to measure the battery level 256: The device-status is not available.
device_status_margin: i32The device margin status -32..32: The demodulation SNR ration in dB 256: The device-status is not available.
device_status_external_power_source: boolDevice is connected to an external power source.
Device battery status is unavailable.
device_status_battery_level: f32Device battery level as a percentage.
last_seen_at: Option<Timestamp>The last time the application-server received any data from the device, or an empty string when the device never sent any data.