Struct chirpstack_api::as_pb::external::api::DeviceProfile [−][src]
pub struct DeviceProfile {Show 31 fields
pub id: String,
pub name: String,
pub organization_id: i64,
pub network_server_id: i64,
pub supports_class_b: bool,
pub class_b_timeout: u32,
pub ping_slot_period: u32,
pub ping_slot_dr: u32,
pub ping_slot_freq: u32,
pub supports_class_c: bool,
pub class_c_timeout: u32,
pub mac_version: String,
pub reg_params_revision: String,
pub rx_delay_1: u32,
pub rx_dr_offset_1: u32,
pub rx_datarate_2: u32,
pub rx_freq_2: u32,
pub factory_preset_freqs: Vec<u32>,
pub max_eirp: u32,
pub max_duty_cycle: u32,
pub supports_join: bool,
pub rf_region: String,
pub supports_32bit_f_cnt: bool,
pub payload_codec: String,
pub payload_encoder_script: String,
pub payload_decoder_script: String,
pub geoloc_buffer_ttl: u32,
pub geoloc_min_buffer_size: u32,
pub tags: HashMap<String, String>,
pub uplink_interval: Option<Duration>,
pub adr_algorithm_id: String,
}Fields
id: StringDevice-profile ID (UUID string).
name: StringDevice-profile name.
organization_id: i64Organization ID to which the service-profile is assigned.
network_server_id: i64Network-server ID on which the service-profile is provisioned.
supports_class_b: boolEnd-Device supports Class B.
class_b_timeout: u32Maximum delay for the End-Device to answer a MAC request or a confirmed DL frame (mandatory if class B mode supported).
ping_slot_period: u32Mandatory if class B mode supported.
ping_slot_dr: u32Mandatory if class B mode supported.
ping_slot_freq: u32Mandatory if class B mode supported.
supports_class_c: boolEnd-Device supports Class C.
class_c_timeout: u32Maximum delay for the End-Device to answer a MAC request or a confirmed DL frame (mandatory if class C mode supported).
mac_version: StringVersion of the LoRaWAN supported by the End-Device.
reg_params_revision: StringRevision of the Regional Parameters document supported by the End-Device.
rx_delay_1: u32Class A RX1 delay (mandatory for ABP).
rx_dr_offset_1: u32RX1 data rate offset (mandatory for ABP).
rx_datarate_2: u32RX2 data rate (mandatory for ABP).
rx_freq_2: u32RX2 channel frequency (mandatory for ABP).
factory_preset_freqs: Vec<u32>List of factory-preset frequencies (mandatory for ABP).
max_eirp: u32Maximum EIRP supported by the End-Device.
max_duty_cycle: u32Maximum duty cycle supported by the End-Device.
supports_join: boolEnd-Device supports Join (OTAA) or not (ABP).
rf_region: StringRF region name.
supports_32bit_f_cnt: boolEnd-Device uses 32bit FCnt (mandatory for LoRaWAN 1.0 End-Device).
payload_codec: StringPayload codec. Leave blank to disable the codec feature.
payload_encoder_script: StringPayload encoder script. Depending the codec, it is possible to provide a script which implements the encoder function.
payload_decoder_script: StringPayload decoder script. Depending the codec, it is possible to provide a script which implements the decoder function.
geoloc_buffer_ttl: u32Geolocation buffer TTL (in seconds). When > 0, uplink RX meta-data will be stored in a buffer so that the meta-data of multiple uplinks can be used for geolocation.
geoloc_min_buffer_size: u32Geolocation minimum buffer size. When > 0, geolocation will only be performed when the buffer has at least the given size.
User defined tags.
uplink_interval: Option<Duration>Uplink interval. This defines the expected uplink interval which the device uses for communication. When the uplink interval has expired and no uplink has been received, the device is considered inactive.
adr_algorithm_id: StringADR algorithm ID. In case this is left blank, or is configured to a non-existing ADR algorithm (plugin), then it falls back to ‘default’.