Struct chirpstack_api::as_pb::integration::JoinEvent [−][src]
pub struct JoinEvent {
pub application_id: u64,
pub application_name: String,
pub device_name: String,
pub dev_eui: Vec<u8>,
pub dev_addr: Vec<u8>,
pub rx_info: Vec<UplinkRxInfo>,
pub tx_info: Option<UplinkTxInfo>,
pub dr: u32,
pub tags: HashMap<String, String>,
pub published_at: Option<Timestamp>,
}Expand description
JoinEvent is the message sent when a device joined the network. Note that this is only sent after the first received uplink after the device (re)activation.
Fields
application_id: u64Application ID.
application_name: StringApplication name.
device_name: StringDevice name.
dev_eui: Vec<u8>Device EUI.
dev_addr: Vec<u8>Device address.
rx_info: Vec<UplinkRxInfo>Receiving gateway RX info.
tx_info: Option<UplinkTxInfo>TX info.
dr: u32Data-rate.
User-defined device tags.
published_at: Option<Timestamp>Published at timestamp.