Struct chirpstack_api::as_pb::HandleUplinkDataRequest [−][src]
pub struct HandleUplinkDataRequest {
pub dev_eui: Vec<u8>,
pub join_eui: Vec<u8>,
pub f_cnt: u32,
pub f_port: u32,
pub adr: bool,
pub dr: u32,
pub tx_info: Option<UplinkTxInfo>,
pub rx_info: Vec<UplinkRxInfo>,
pub data: Vec<u8>,
pub device_activation_context: Option<DeviceActivationContext>,
pub confirmed_uplink: bool,
}Fields
dev_eui: Vec<u8>DevEUI EUI (8 bytes).
join_eui: Vec<u8>Join EUI used for OTAA activation (8 bytes).
f_cnt: u32Frame-counter.
f_port: u32Frame port.
adr: boolADR enabled.
dr: u32Data-rate.
tx_info: Option<UplinkTxInfo>TX meta-data.
rx_info: Vec<UplinkRxInfo>RX meta-data.
data: Vec<u8>Received data (encrypted).
device_activation_context: Option<DeviceActivationContext>Device activation context.
This field is only set on the first uplink frame when the security context has changed (e.g. a new OTAA (re)activation).
confirmed_uplink: boolUplink was of type confirmed.