pub enum TimingInfo {
ImmediatelyTimingInfo(ImmediatelyTimingInfo),
DelayTimingInfo(DelayTimingInfo),
GpsEpochTimingInfo(GpsEpochTimingInfo),
}Variants
ImmediatelyTimingInfo(ImmediatelyTimingInfo)
Immediately timing information.
DelayTimingInfo(DelayTimingInfo)
Context based delay timing information.
GpsEpochTimingInfo(GpsEpochTimingInfo)
GPS Epoch timing information.
Implementations
Sourceimpl TimingInfo
impl TimingInfo
Sourcepub fn merge(
field: &mut Option<TimingInfo>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<TimingInfo>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.